@@ -413,12 +413,13 @@ ic.var <-
 
 # test sulla varianza 
 test.var <- function (x, var0, alternative = 
- c("greater", "less"), alpha = 0.05){
+ "greater", alpha = 0.05){
   if(missing(var0))
    stop("specificare l'ipotesi nulla var0")
   if(missing(x))
    stop("specificare i dati x")
-
+  if(!(alternative %in% c("greater","less")))
+   stop("'alternative' deve essere uno tra 'greater' o 'less'")
   n <- length(x)
   stat <- (n-1)*var(x)/var0
   cat("\n Ipotesi nulla => H0 : sigma2 =",var0)
@@ -436,8 +437,7 @@ test.var <- function (x, var0, alternative =
     cat("\n Decisione: si rifuta H0\n")
    else
     cat("\n Decisione: non si rifuta H0\n")
-  }
-  else if(alternative == "less"){
+  } else {
    soglia <- qchisq(alpha,df=n-1)
    cat("\n p-value:",pchisq(stat,df=n-1),",")    
    cat(" livello del test:",alpha)
